@@ -22,5 +22,5 @@ import numpy as np
 from scipy.constants import c
 
 rad_to_arcsec = 3600 * 180 / np.pi
-sterad_to_arsec = rad_to_arcsec ** 2
+sterad_to_arcsec = rad_to_arcsec ** 2
 deg_to_rad = np.pi / 180
