@@ -148,6 +148,17 @@ def parse_parameters(*args):
                  ' {}'.format(model['input_output']['uvtable_filename']))
 
     # Sanity check some of the .json parameters
+    if model['hyperparameters']['method'] not in ["Normal", "LogNormal"]:
+        err = ValueError("method should be 'Normal' or 'LogNormal'")
+        raise err
+
+    if model['hyperparameters']['method'] == 'LogNormal' and \
+       model['hyperparameters']['p0'] > 1e-30:
+        err = ValueError("p0 = {}. If method is 'LogNormal', p0 should be "
+                         "<~ 1e-35 (we recommend 1e-35)"
+                         ".".format(model['hyperparameters']['p0']))
+        raise err
+
     if model['plotting']['diag_plot']:
         if model['plotting']['iter_plot_range'] is not None:
             err = ValueError("iter_plot_range should be 'null' (None)"
@@ -160,7 +171,7 @@ def parse_parameters(*args):
                 raise err
 
     if model['plotting']['stretch'] not in ["power", "asinh"]:
-        err = ValueError("stretch should be 'power'  or 'asinh'")
+        err = ValueError("stretch should be 'power' or 'asinh'")
         raise err
 
     if model['modify_data']['baseline_range'] is not None:
@@ -393,15 +404,19 @@ def perform_fit(u, v, vis, weights, geom, model):
                                     alpha=model['hyperparameters']['alpha'],
                                     weights_smooth=model['hyperparameters']['wsmooth'],
                                     tol=model['hyperparameters']['iter_tol'],
+                                    method=model['hyperparameters']['method'],
                                     max_iter=model['hyperparameters']['max_iter'],
-                                    store_iteration_diagnostics=need_iterations
+                                    store_iteration_diagnostics=need_iterations,
+                                    assume_optically_thick=model['geometry']['rescale_flux']
                                     )
 
     sol = FF.fit(u, v, vis, weights)
 
-    if model['hyperparameters']['nonnegative']:
+    if model['hyperparameters']['nonnegative'] and \
+       model['hyperparameters']['method'] == 'Normal':
         # Add the best fit nonnegative solution to the fit's `sol` object
-        logging.info('  `nonnegative` is `true` in your parameter file --> Storing the best fit nonnegative profile as the attribute `nonneg` in the `sol` object')
+        logging.info('  `nonnegative` is `true` in your parameter file --> '\
+                    'Storing the best fit nonnegative profile as the attribute `nonneg` in the `sol` object')
         setattr(sol, '_nonneg', sol.solve_non_negative())
 
     logging.info('    Time taken to fit profile (with {:.0e} visibilities and'
@@ -477,8 +492,6 @@ def run_multiple_fits(u, v, vis, weights, geom, model):
         multifit_fig, multifit_axes = make_figs.make_multifit_fig(u=u, v=v, vis=vis,
                                                                weights=weights, sols=sols,
                                                                bin_widths=model['plotting']['bin_widths'],
-                                                               varied_pars=['alpha', 'wsmooth'],
-                                                               varied_vals=[alphas, ws],
                                                                dist=model['plotting']['distance'],
                                                                force_style=model['plotting']['force_style'],
                                                                save_prefix=model['input_output']['save_prefix'],
@@ -529,7 +542,7 @@ def output_results(u, v, vis, weights, sol, geom, model, iteration_diagnostics=N
             model['input_output']['save_vis_fit'],
             model['input_output']['save_uvtables']
             ]):
-            
+
         io.save_fit(u, v, vis, weights, sol,
                     model['input_output']['save_prefix'],
                     model['input_output']['save_solution'],
@@ -640,9 +653,9 @@ def output_results(u, v, vis, weights, sol, geom, model, iteration_diagnostics=N
             clean_profile = {'r': r_clean, 'I': I_clean, 'lo_err': lo_err_clean,
                              'hi_err': hi_err_clean}
 
-            mean_convolved = None
+            MAP_convolved = None
             if model['analysis']['clean_beam']['bmaj'] is not None:
-                mean_convolved = utilities.convolve_profile(sol.r, sol.mean,
+                MAP_convolved = utilities.convolve_profile(sol.r, sol.I,
                                                             geom.inc, geom.PA,
                                                             model['analysis']['clean_beam'])
 
@@ -653,7 +666,7 @@ def output_results(u, v, vis, weights, sol, geom, model, iteration_diagnostics=N
                                                                         stretch=model['plotting']['stretch'],
                                                                         gamma=model['plotting']['gamma'],
                                                                         asinh_a=model['plotting']['asinh_a'],
-                                                                        mean_convolved=mean_convolved,
+                                                                        MAP_convolved=MAP_convolved,
                                                                         dist=model['plotting']['distance'],
                                                                         force_style=model['plotting']['force_style'],
                                                                         save_prefix=model['input_output']['save_prefix']
@@ -700,7 +713,7 @@ def perform_bootstrap(u, v, vis, weights, geom, model):
 
     if model['hyperparameters']['nonnegative']:
         logging.info('  `nonnegative` is `true` in your parameter file --> '
-                     'The best fit nonnegative profile (rather than the mean '
+                     'The best fit nonnegative profile (rather than the MAP '
                      'profile) will be saved and used to generate the bootstrap '
                      'figure')
 
@@ -716,7 +729,7 @@ def perform_bootstrap(u, v, vis, weights, geom, model):
         if model['hyperparameters']['nonnegative']:
             profiles_bootstrap.append(sol._nonneg)
         else:
-            profiles_bootstrap.append(sol.mean)
+            profiles_bootstrap.append(sol.I)
 
     bootstrap_path = model['input_output']['save_prefix'] + '_bootstrap.npz'
 
