@@ -102,6 +102,9 @@ def deproject(u, v, inc, PA, inverse=False):
         Deprojected u-points
     vp : array, size = N, unit = :math:`\lambda`
         Deprojected v-points
+    wp : array of real, size = N, unit = :math:`\lambda`
+        Fourier w-points of the deprojected visibilities. Only returned if
+        deprojecting.
 
     """
 
@@ -118,11 +121,53 @@ def deproject(u, v, inc, PA, inverse=False):
     up = u * cos_t - v * sin_t
     vp = u * sin_t + v * cos_t
 
+    if inverse:
+        return up, vp
+    else:
     #   Deproject
-    if not inverse:
-        up *= np.cos(inc)
+        wp = up * np.sin(inc)
+        up = up * np.cos(inc)
 
-    return up, vp
+        return up, vp, wp
+
+def rescale_total_flux(V, weights, inc):
+    r"""
+    Scale the visibility amplitudes (and weights) according to the source
+    inclination.
+
+    Parameters
+    ----------
+    V : array of real, size = N, unit = Jy
+        Real component of the complex, deprojected visibilities
+    weights : array of real, size = N, unit = Jy
+        Weights on the visibilities
+    inc : float, unit = deg
+        Inclination of the disc
+    
+    Returns
+    -------
+    V_scaled : array of real, size = N, unit = Jy
+        Rescaled real component of the complex visibilities
+    weights_scaled : array of real, size = N, unit = Jy
+        Rescaled weights on the visibilities
+    
+    Notes
+    -----
+    This scaling accounts for the difference between the inclined (observed)
+    brightness and the assumed face-on brightness, assuming the
+    emission is optically thick. The source's integrated (2D) flux is assumed
+    to be
+        :math:`F = \cos(i) \int_r^{r=R}{I(r) 2 \pi r dr}`.
+    No rescaling would be appropriate in the optically thin limit.
+    """
+
+    # Ensure we're only altering the real component of the visibilities
+    V = V.real
+
+    V_scaled = V / np.cos(inc * deg_to_rad)
+    weights_scaled = weights * np.cos(inc * deg_to_rad) ** 2
+
+    return V_scaled, weights_scaled
 
 
 class SourceGeometry(object):
@@ -154,7 +199,7 @@ class SourceGeometry(object):
         self._dRA = dRA
         self._dDec = dDec
 
-    def apply_correction(self, u, v, V):
+    def apply_correction(self, u, v, V, use3D=False):
         r"""
         Correct the phase centre and deproject the visibilities
 
@@ -166,6 +211,9 @@ class SourceGeometry(object):
             v-points of the visibilities
         V : array of real, size = N, units = Jy
             Complex visibilites
+        use3D : bool, default=False
+            If True, also return the 3rd compoent of the
+            de-projected visibilities, wp.
 
         Returns
         -------
@@ -173,14 +221,20 @@ class SourceGeometry(object):
             Corrected u-points of the visibilities
         vp : array of real, size = N, unit = :math:`\lambda`
             Corrected v-points of the visibilities
+        wp : array of real, size = N, unit = :math:`\lambda`
+            [Optional] Corrected w-points of the visibilities
         Vp : array of real, size = N, unit = Jy
             Corrected complex visibilites
 
         """
         Vp = apply_phase_shift(u, v, V, self._dRA, self._dDec, inverse=True)
-        up, vp = deproject(u, v, self._inc, self._PA)
+        up, vp, wp = deproject(u, v, self._inc, self._PA)
+
+        if use3D:
+            return up, vp, wp, Vp
+        else:
+            return up, vp, Vp
 
-        return up, vp, Vp
 
     def undo_correction(self, u, v, V):
         r"""
@@ -203,19 +257,64 @@ class SourceGeometry(object):
             Corrected v-points of the visibilities
         Vp : array of real, size = N, unit = Jy
             Corrected complex visibilites
+
         """
         up, vp = self.reproject(u, v)
         Vp = apply_phase_shift(up, vp, V, self._dRA, self._dDec, inverse=False)
 
         return up, vp, Vp
 
-    def deproject(self, u, v):
-        """Convert uv-points from sky-plane to deprojected space"""
-        return deproject(u, v, self._inc, self._PA)
+    def deproject(self, u, v, use3D=False):
+        r"""Convert uv-points from sky-plane to deprojected space (u,v)
+        
+        Parameters
+        ----------
+        u : array of real, size = N, unit = :math:`\lambda`
+            u-points of the visibilities
+        v : array of real, size = N, unit = :math:`\lambda`
+            v-points of the visibilities
+        use3D : bool, default=False
+            If True, also return the 3rd compoent of the
+            de-projected visibilities, wp.
+
+        Returns
+        -------
+        up : array of real, size = N, unit = :math:`\lambda`
+            Corrected u-points of the visibilities
+        vp : array of real, size = N, unit = :math:`\lambda`
+            Corrected v-points of the visibilities
+        wp : array of real, size = N, unit = :math:`\lambda`
+            [Optional] Corrected w-points of the visibilities
+            
+        """
+        if use3D:
+            return deproject(u, v, self._inc, self._PA)
+        else:
+            return deproject(u, v, self._inc, self._PA)[:2]
 
     def reproject(self, u, v):
-        """Convert uv-points from deprojected space to sky-plane"""
+        r"""Convert uv-points from deprojected space to sky-plane
+        
+        Parameters
+        ----------
+        u : array of real, size = N, unit = :math:`\lambda`
+            u-points of the visibilities
+        v : array of real, size = N, unit = :math:`\lambda`
+            v-points of the visibilities
+
+        Returns
+        -------
+        up : array of real, size = N, unit = :math:`\lambda`
+            Corrected u-points of the visibilities
+        vp : array of real, size = N, unit = :math:`\lambda`
+            Corrected v-points of the visibilities
+            
+        """
         return deproject(u, v, self._inc, self._PA, inverse=True)
+        
+
+    def rescale_total_flux(self, V, weights):
+        return rescale_total_flux(V, weights, self._inc)
 
     def fit(self, u, v, V, weights):
         r"""
@@ -259,6 +358,16 @@ class SourceGeometry(object):
         """Inclination of the disc, unit = rad"""
         return self._inc
 
+    @property
+    def rescale_factor(self):
+        """Factor used to rescale the visibility amplitudes, unit = 1 / rad"""
+        return 1.0 / np.cos(self._inc * deg_to_rad)
+        
+    def __repr__(self):
+        return "SourceGeometry(inc={}, PA={}, dRA={}, dDEC={})".format(
+            self.inc, self.PA, self.dRA, self.dDec
+        )
+
 
 class FixedGeometry(SourceGeometry):
     """
@@ -286,7 +395,12 @@ class FixedGeometry(SourceGeometry):
     def __init__(self, inc, PA, dRA=0.0, dDec=0.0):
         super(FixedGeometry, self).__init__(inc, PA, dRA, dDec)
 
+    def __repr__(self):
+        return "FixedGeometry(inc={}, PA={}, dRA={}, dDEC={})".format(
+            self.inc, self.PA, self.dRA, self.dDec
+        )
 
+        
 class FitGeometryGaussian(SourceGeometry):
     """
     Determine the disc geometry by fitting a Gaussian in Fourier space.
@@ -521,7 +635,6 @@ class FitGeometryFourierBessel(SourceGeometry):
     Process prior. For this reason, a small number of bins is
     recommended for fit stability.
 
-
     Parameters
     ----------
     Rmax : float, unit = arcsec
@@ -543,6 +656,7 @@ class FitGeometryFourierBessel(SourceGeometry):
     verbose : bool, default=False
         Determines whether to print the iteration progress.
     """
+
     def __init__(self, Rmax, N, inc_pa=None, phase_centre=None, guess=None,
                  verbose=False):
         self._N = N
