@@ -32,15 +32,13 @@ from frank.plot import (
     plot_brightness_profile,
     plot_vis_quantity,
     plot_vis_hist,
-    plot_profile_iterations,
+    plot_iterations,
     plot_2dsweep,
-    plot_pwr_spec_iterations,
     plot_convergence_criterion
 )
 
 # Suppress some benign warnings
 import warnings
-warnings.filterwarnings('ignore', '.*compatible with tight_layout.*')
 warnings.filterwarnings('ignore', '.*handles with labels found.*')
 
 
@@ -168,10 +166,9 @@ def make_deprojection_fig(u, v, vis, weights, geom, bin_widths, logx=False,
     ax0.legend(loc=0)
     ax1.legend(loc=0)
 
-    plt.tight_layout()
-
     if save_prefix:
-        plt.savefig(save_prefix + '_frank_deprojection.png', dpi=300)
+        plt.savefig(save_prefix + '_frank_deprojection.png', dpi=300,
+                    bbox_inches='tight')
         plt.close()
 
     return fig, axes
@@ -260,13 +257,14 @@ def make_quick_fig(u, v, vis, weights, sol, bin_widths, priors, dist=None,
 
         axes = [ax0, ax1, ax2, ax3, ax4, ax5]
 
-        plot_brightness_profile(sol.r, sol.mean / 1e10, ax0, c='r', label='frank')
+        plot_brightness_profile(sol.r, sol.I / 1e10, ax0, c='r', label='frank')
+
         if dist:
-            ax0_5 = plot_brightness_profile(sol.r, sol.mean / 1e10, ax0, dist=dist, c='r')
+            ax0_5 = plot_brightness_profile(sol.r, sol.I / 1e10, ax0, dist=dist, c='r')
             xlims = ax0.get_xlim()
             ax0_5.set_xlim(np.multiply(xlims, dist))
 
-        plot_brightness_profile(sol.r, sol.mean / 1e10, ax1, c='r', label='frank')
+        plot_brightness_profile(sol.r, sol.I / 1e10, ax1, c='r', label='frank')
 
         u_deproj, v_deproj, vis_deproj = sol.geometry.apply_correction(u, v, vis)
         baselines = (u_deproj**2 + v_deproj**2)**.5
@@ -292,17 +290,18 @@ def make_quick_fig(u, v, vis, weights, sol, bin_widths, priors, dist=None,
 
         # Make a guess of good y-bounds for zooming in on the visibility fit
         # in linear-y
-        zoom_ylim_guess = abs(vis_fit_kl[np.int(.5 * len(vis_fit_kl)):]).max()
+        zoom_ylim_guess = abs(vis_fit_kl[int(.5 * len(vis_fit_kl)):]).max()
         zoom_bounds = [-1.1 * zoom_ylim_guess, 1.1 * zoom_ylim_guess]
         ax3.set_ylim(zoom_bounds)
 
         plot_vis_quantity(grid / 1e6, vis_fit_kl, ax3, c='r', label='frank', zorder=10)
 
-        vmax = sol.mean.max()
+        vmax = sol.I.max()
         if stretch == 'asinh':
-            vmin = max(0, min(sol.mean))
+            vmin = max(0, min(sol.I))
             from astropy.visualization.mpl_normalize import simple_norm
-            norm = simple_norm(sol.mean, stretch='asinh', asinh_a=asinh_a, min_cut=vmin)
+            norm = simple_norm(sol.I, stretch='asinh', asinh_a=asinh_a, 
+                               min_cut=vmin, max_cut=vmax)
         elif stretch == 'power':
             vmin = 0
             norm = PowerNorm(gamma, vmin, vmax)
@@ -310,11 +309,10 @@ def make_quick_fig(u, v, vis, weights, sol, bin_widths, priors, dist=None,
             err = ValueError("Unknown 'stretch'. Should be one of 'power' or 'asinh'")
             raise err
 
-        plot_2dsweep(sol.r, sol.mean, ax=ax4, cmap='inferno', norm=norm,
-                    vmin=vmin, vmax=vmax, project=False)
-        plot_2dsweep(sol.r, sol.mean, ax=ax5, cmap='inferno', norm=norm,
-                    vmin=vmin, vmax=vmax, project=True,
-                    geom=sol.geometry)
+        plot_2dsweep(sol.r, sol.I, ax=ax4, cmap='inferno', norm=norm,
+                    project=False)
+        plot_2dsweep(sol.r, sol.I, ax=ax5, cmap='inferno', norm=norm,
+                    project=True, geom=sol.geometry)
 
         ax1.set_xlabel('r ["]')
         ax0.set_ylabel(r'Brightness [$10^{10}$ Jy sr$^{-1}$]')
@@ -330,7 +328,9 @@ def make_quick_fig(u, v, vis, weights, sol, bin_widths, priors, dist=None,
             ax2.set_xscale('log')
             ax3.set_xscale('log')
 
-        ax2.set_xlim(right=max(baselines) / 1e6 * 1.2)
+            ax2.set_xlim(right=max(baselines) / 1e6 * 1.2)
+        else:
+            ax2.set_xlim(0, max(baselines) / 1e6 * 1.2)
         xlims = ax2.get_xlim()
         ax3.set_xlim(xlims)
 
@@ -342,10 +342,9 @@ def make_quick_fig(u, v, vis, weights, sol, bin_widths, priors, dist=None,
         plt.setp(ax0.get_xticklabels(), visible=False)
         plt.setp(ax2.get_xticklabels(), visible=False)
 
-        plt.tight_layout()
-
         if save_prefix:
-            plt.savefig(save_prefix + '_frank_fit_quick.png', dpi=300)
+            plt.savefig(save_prefix + '_frank_fit_quick.png', dpi=300,
+                        bbox_inches='tight')
             plt.close()
 
     return fig, axes
@@ -447,13 +446,14 @@ def make_full_fig(u, v, vis, weights, sol, bin_widths, priors,
         axes = [ax0, ax1, ax2, ax3, ax4, ax5, ax6, ax7, ax8, ax9]
 
         # Plot the fitted brightness profile in linear- and log-y
-        plot_brightness_profile(sol.r, sol.mean / 1e10, ax0, c='r', label='frank')
+        plot_brightness_profile(sol.r, sol.I / 1e10, ax0, c='r', label='frank')
+
         if dist:
-            ax0_5 = plot_brightness_profile(sol.r, sol.mean / 1e10, ax0, dist=dist, c='r')
+            ax0_5 = plot_brightness_profile(sol.r, sol.I / 1e10, ax0, dist=dist, c='r')
             xlims = ax0.get_xlim()
             ax0_5.set_xlim(np.multiply(xlims, dist))
 
-        plot_brightness_profile(sol.r, sol.mean / 1e10, ax1, c='r', label='frank')
+        plot_brightness_profile(sol.r, sol.I / 1e10, ax1, c='r', label='frank')
 
         # Apply deprojection to the provided (u, v) coordinates
         # and visibility amplitudes
@@ -469,7 +469,7 @@ def make_full_fig(u, v, vis, weights, sol, bin_widths, priors,
 
         # Make a guess of good y-bounds for zooming in on the visibility fit
         # in linear-y
-        zoom_ylim_guess = abs(vis_fit_kl[np.int(.5 * len(vis_fit_kl)):]).max()
+        zoom_ylim_guess = abs(vis_fit_kl[int(.5 * len(vis_fit_kl)):]).max()
         zoom_bounds = [-1.1 * zoom_ylim_guess, 1.1 * zoom_ylim_guess]
         ax4.set_ylim(zoom_bounds)
 
@@ -491,45 +491,46 @@ def make_full_fig(u, v, vis, weights, sol, bin_widths, priors,
             rmse = (np.mean(resid**2))**.5
 
             # Plot the observed, binned visibilities (with errorbars) and the residuals
-            plot_vis_quantity(binned_vis.uv, vis_re_kl, ax3, c=cs[i],
+            plot_vis_quantity(binned_vis.uv / 1e6, vis_re_kl, ax3, c=cs[i],
                      marker=ms[i], ls='None',
                      label=r'Obs., {:.0f} k$\lambda$ bins'.format(bin_widths[i]/1e3))
 
-            plot_vis_quantity(binned_vis.uv, vis_re_kl, ax4, c=cs[i],
+            plot_vis_quantity(binned_vis.uv / 1e6, vis_re_kl, ax4, c=cs[i],
                      marker=ms[i], ls='None',
                      label=r'Obs., {:.0f} k$\lambda$ bins'.format(bin_widths[i]/1e3))
 
-            plot_vis_quantity(binned_vis.uv, vis_im_kl, ax6, c=cs[i],
+            plot_vis_quantity(binned_vis.uv / 1e6, vis_im_kl, ax6, c=cs[i],
                      marker=ms[i], ls='None',
                      label=r'Obs., {:.0f} k$\lambda$ bins'.format(bin_widths[i]/1e3))
 
-            plot_vis_quantity(binned_vis.uv, resid, ax5, c=cs[i], marker=ms[i], ls='None',
+            plot_vis_quantity(binned_vis.uv / 1e6, resid, ax5, c=cs[i], marker=ms[i], ls='None',
                            label=r'{:.0f} k$\lambda$ bins, RMSE {:.3f} mJy'.format(bin_widths[i]/1e3, rmse))
 
             # Plot a histogram of the observed visibilties to examine how the
             # visibility count varies with baseline
-            plot_vis_hist(binned_vis, ax8, color=hist_cs[i],
+            plot_vis_hist(binned_vis, ax8, rescale=1e6, color=hist_cs[i],
                           label=r'Obs., {:.0f} k$\lambda$ bins'.format(bin_widths[i]/1e3))
             # Plot the binned data signal-to-noise as a function of baseline
-            plot_vis_quantity(binned_vis.uv,
+            plot_vis_quantity(binned_vis.uv / 1e6,
                           binned_vis.V.real**2 / binned_vis.error.real**2,
                           ax9, color=hist_cs[i], marker=ms[i], ls='None',
                           label=r'{:.0f} k$\lambda$ bins'.format(bin_widths[i]/1e3))
 
         # Plot the visibility domain frank fit in log-y
-        plot_vis_quantity(grid, vis_fit_kl, ax3, c='r', label='frank')
-        plot_vis_quantity(grid, vis_fit_kl, ax4, c='r', label='frank')
+        plot_vis_quantity(grid / 1e6, vis_fit_kl, ax3, c='r', label='frank')
+        plot_vis_quantity(grid / 1e6, vis_fit_kl, ax4, c='r', label='frank')
 
         # Plot the frank inferred power spectrum
-        plot_vis_quantity(sol.q, sol.power_spectrum, ax7)
+        plot_vis_quantity(sol.q / 1e6, sol.power_spectrum, ax7)
 
         # Plot a sweep over 2\pi of the frank 1D fit
         # (analogous to a model image of the source)
-        vmax = sol.mean.max()
+        vmax = sol.I.max()
         if stretch == 'asinh':
-            vmin = max(0, min(sol.mean))
+            vmin = max(0, min(sol.I))
             from astropy.visualization.mpl_normalize import simple_norm
-            norm = simple_norm(sol.mean, stretch='asinh', asinh_a=asinh_a, min_cut=vmin)
+            norm = simple_norm(sol.I, stretch='asinh', asinh_a=asinh_a, 
+                               min_cut=vmin, max_cut=vmax)
         elif stretch == 'power':
             vmin = 0
             norm = PowerNorm(gamma, vmin, vmax)
@@ -537,9 +538,8 @@ def make_full_fig(u, v, vis, weights, sol, bin_widths, priors,
             err = ValueError("Unknown 'stretch'. Should be one of 'power' or 'asinh'")
             raise err
 
-        plot_2dsweep(sol.r, sol.mean, ax=ax2, cmap='inferno', norm=norm,
-                    vmin=vmin, vmax=vmax, project=True,
-                    geom=sol.geometry)
+        plot_2dsweep(sol.r, sol.I, ax=ax2, cmap='inferno', norm=norm,
+                    project=True, geom=sol.geometry)
 
         ax1.set_xlabel('r ["]')
         ax0.set_ylabel(r'Brightness [$10^{10}$ Jy sr$^{-1}$]')
@@ -553,8 +553,9 @@ def make_full_fig(u, v, vis, weights, sol, bin_widths, priors,
         if logx:
             for aa in axs:
                 aa.set_xscale('log')
-
-        ax3.set_xlim(right=max(baselines) * 1.2)
+            ax3.set_xlim(right=max(baselines) / 1e6 * 1.2)
+        else:
+            ax3.set_xlim(0, max(baselines) / 1e6 * 1.2)
         xlims = ax3.get_xlim()
         for aa in axs:
             aa.set_xlim(xlims)
@@ -562,7 +563,6 @@ def make_full_fig(u, v, vis, weights, sol, bin_widths, priors,
         ax7.set_yscale('log')
         ax8.set_yscale('log')
 
-        ax7.set_yticks([1e-15, 1e-10, 1e-5, 1])
         ax8.set_yticks([1, 10, 1e2, 1e3])
 
         ax9.set_yscale('log')
@@ -576,13 +576,13 @@ def make_full_fig(u, v, vis, weights, sol, bin_widths, priors,
             ax5.set_ylabel('Norm. residual')
         else:
             ax5.set_ylabel('Residual [mJy]')
-        ax5.set_xlabel(r'Baseline [$\lambda$]')
+        ax5.set_xlabel(r'Baseline [M$\lambda$]')
 
         ax6.set_ylabel('Im(V) [mJy]')
         ax7.set_ylabel(r'Power [Jy$^2$]')
         ax8.set_ylabel('Count')
         ax9.set_ylabel(r'SNR=$\mu_{\rm bin}^2 / \sigma_{\rm bin}^2$')
-        ax9.set_xlabel(r'Baseline [$\lambda$]')
+        ax9.set_xlabel(r'Baseline [M$\lambda$]')
 
         axs = [ax0, ax3, ax4, ax6, ax7, ax8]
         for aa in axs:
@@ -669,28 +669,27 @@ def make_diag_fig(r, q, iteration_diagnostics, iter_plot_range=None, logx=False,
 
         axes = [ax0, ax1, ax2, ax3, ax4]
 
-        profile_iter = iteration_diagnostics['mean']
+        profile_iter = iteration_diagnostics['MAP']
         profile_iter_toplot = [x / 1e10 for x in profile_iter]
         pwr_spec_iter = iteration_diagnostics['power_spectrum']
         num_iter = iteration_diagnostics['num_iterations']
 
-        plot_profile_iterations(r, profile_iter_toplot, iter_plot_range, ax0)
+        plot_iterations(r, profile_iter_toplot, iter_plot_range, ax0)
 
         # Plot the difference in the profile between the last 100 iterations
         iter_plot_range_end = [max(iter_plot_range[1] - 100, 0),
                                iter_plot_range[1] - 1]
 
-        plot_profile_iterations(r, np.diff(profile_iter_toplot, axis=0),
+        plot_iterations(r, np.diff(profile_iter_toplot, axis=0),
                                 iter_plot_range_end, ax1,
                                 cmap=plt.cm.cividis)  # pylint: disable=no-member
 
-        plot_pwr_spec_iterations(q, pwr_spec_iter, iter_plot_range, ax2)
+        plot_iterations(q, pwr_spec_iter, iter_plot_range, ax2)
 
         # Plot the difference in the power spectrum between the last 100 iterations
-        plot_pwr_spec_iterations(q, abs(np.diff(pwr_spec_iter, axis=0)),
+        plot_iterations(q, abs(np.diff(pwr_spec_iter, axis=0)),
                                  iter_plot_range_end, ax3,
-                                 cmap=plt.cm.cividis,  # pylint: disable=no-member
-                                 bbox_x=.45)
+                                 cmap=plt.cm.cividis)  # pylint: disable=no-member
 
         plot_convergence_criterion(profile_iter_toplot, num_iter, ax4, c='k')
 
@@ -718,10 +717,9 @@ def make_diag_fig(r, q, iteration_diagnostics, iter_plot_range=None, logx=False,
         plt.setp(ax0.get_xticklabels(), visible=False)
         plt.setp(ax2.get_xticklabels(), visible=False)
 
-        plt.tight_layout()
-
         if save_prefix:
-            plt.savefig(save_prefix + '_frank_fit_diag.png', dpi=300)
+            plt.savefig(save_prefix + '_frank_fit_diag.png', dpi=300,
+                        bbox_inches='tight')
             plt.close()
 
     return fig, axes, iter_plot_range
@@ -729,7 +727,7 @@ def make_diag_fig(r, q, iteration_diagnostics, iter_plot_range=None, logx=False,
 
 def make_clean_comparison_fig(u, v, vis, weights, sol, clean_profile,
                               bin_widths, stretch='power',
-                              gamma=1.0, asinh_a=0.02, mean_convolved=None,
+                              gamma=1.0, asinh_a=0.02, MAP_convolved=None,
                               dist=None, logx=False, logy=False, ylims=None,
                               force_style=True, save_prefix=None,
                               figsize=(8, 10)):
@@ -768,7 +766,7 @@ def make_clean_comparison_fig(u, v, vis, weights, sol, clean_profile,
         gamma=1.0 yields a linear colormap
     asinh_a : float, default = 0.02
         Scale parameter for an asinh stretch
-    mean_convolved : None (default) or array, unit = Jy / sr
+    MAP_convolved : None (default) or array, unit = Jy / sr
         frank brightness profile convolved with a CLEAN beam
         (see utilities.convolve_profile).
         The assumed unit is for the x-label
@@ -824,14 +822,14 @@ def make_clean_comparison_fig(u, v, vis, weights, sol, clean_profile,
                                 low_uncer=low_uncer, high_uncer=high_uncer,
                                 c='b', ls='--', label='CLEAN')
 
-        plot_brightness_profile(sol.r, sol.mean / 1e10, ax0, c='r', ls=':', label='frank')
+        plot_brightness_profile(sol.r, sol.I / 1e10, ax0, c='r', ls=':', label='frank')
 
-        if mean_convolved is not None:
-            plot_brightness_profile(sol.r, mean_convolved / 1e10, ax0, c='k', ls='-',
+        if MAP_convolved is not None:
+            plot_brightness_profile(sol.r, MAP_convolved / 1e10, ax0, c='k', ls='-',
                                     label='frank, convolved')
 
         if dist:
-            ax0_5 = plot_brightness_profile(sol.r, sol.mean / 1e10, ax0, dist=dist, c='r', ls=':')
+            ax0_5 = plot_brightness_profile(sol.r, sol.I / 1e10, ax0, dist=dist, c='r', ls=':')
 
         u_deproj, v_deproj, vis_deproj = sol.geometry.apply_correction(u, v, vis)
         baselines = (u_deproj**2 + v_deproj**2)**.5
@@ -886,14 +884,15 @@ def make_clean_comparison_fig(u, v, vis, weights, sol, clean_profile,
         if ylims:
             ax1.set_ylim(ylims)
 
-        if mean_convolved is not None:
-            vmax = max(sol.mean.max(), mean_convolved.max(), clean_profile['I'].max())
+        if MAP_convolved is not None:
+            vmax = max(sol.I.max(), MAP_convolved.max(), clean_profile['I'].max())
         else:
-            vmax = max(sol.mean.max(), clean_profile['I'].max())
+            vmax = max(sol.I.max(), clean_profile['I'].max())
         if stretch == 'asinh':
-            vmin = max(0, min(sol.mean))
+            vmin = max(0, min(sol.I))
             from astropy.visualization.mpl_normalize import simple_norm
-            norm = simple_norm(sol.mean, stretch='asinh', asinh_a=asinh_a, min_cut=vmin)
+            norm = simple_norm(sol.I, stretch='asinh', asinh_a=asinh_a, 
+                               min_cut=vmin, max_cut=vmax)
         elif stretch == 'power':
             vmin = 0
             norm = PowerNorm(gamma, vmin, vmax)
@@ -901,11 +900,11 @@ def make_clean_comparison_fig(u, v, vis, weights, sol, clean_profile,
             err = ValueError("Unknown 'stretch'. Should be one of 'power' or 'asinh'")
             raise err
 
-        plot_2dsweep(sol.r, sol.mean, ax=ax2, cmap='inferno', norm=norm, vmin=0,
-                    vmax=vmax, xmax=sol.Rmax, plot_colorbar=True)
-        if mean_convolved is not None:
-            plot_2dsweep(sol.r, mean_convolved, ax=ax3, cmap='inferno', norm=norm,
-                        vmin=0, vmax=vmax, xmax=sol.Rmax, plot_colorbar=True)
+        plot_2dsweep(sol.r, sol.I, ax=ax2, cmap='inferno', norm=norm,
+                    xmax=sol.Rmax, plot_colorbar=True)
+        if MAP_convolved is not None:
+            plot_2dsweep(sol.r, MAP_convolved, ax=ax3, cmap='inferno', norm=norm,
+                        xmax=sol.Rmax, plot_colorbar=True)
 
         # Interpolate the CLEAN profile onto the frank grid to ensure the CLEAN
         # swept 'image' has the same pixel resolution as the frank swept 'images'
@@ -913,7 +912,7 @@ def make_clean_comparison_fig(u, v, vis, weights, sol, clean_profile,
         interp = interp1d(clean_profile['r'], clean_profile['I'])
         regrid_I_clean = interp(sol.r)
         plot_2dsweep(sol.r, regrid_I_clean, ax=ax4, cmap='inferno', norm=norm,
-                    vmin=0, vmax=vmax, xmax=sol.Rmax, plot_colorbar=True)
+                    xmax=sol.Rmax, plot_colorbar=True)
 
         ax0.legend(loc='best')
         ax1.legend(loc='best', ncol=2)
@@ -955,8 +954,8 @@ def make_clean_comparison_fig(u, v, vis, weights, sol, clean_profile,
     return fig, axes
 
 
-def make_multifit_fig(u, v, vis, weights, sols, bin_widths, varied_pars,
-                      varied_vals, dist=None, logx=False, force_style=True,
+def make_multifit_fig(u, v, vis, weights, sols, bin_widths, dist=None,
+                      logx=False, force_style=True,
                       save_prefix=None, figsize=(8, 8)
                      ):
     r"""
@@ -976,10 +975,6 @@ def make_multifit_fig(u, v, vis, weights, sols, bin_widths, varied_pars,
         (see frank.radial_fitters.FrankFitter), for each of multiple fits
     bin_widths : list, unit = \lambda
         Bin widths in which to bin the observed visibilities
-    varied_pars : list of strings
-        Names of the `hyperparameters` that were varied over multiple fits
-    varied_vals : nested list of floats
-        Values for the `hyperparameters` that were varied over multiple fits
     dist : float, optional, unit = AU, default = None
         Distance to source, used to show second x-axis in [AU]
     logx : bool, default = False
@@ -1044,25 +1039,16 @@ def make_multifit_fig(u, v, vis, weights, sols, bin_widths, varied_pars,
                      marker=ms[i], ls='None',
                      label=r'Obs.<0, {:.0f} k$\lambda$ bins'.format(bin_widths[i]/1e3))
 
-        # Alter the lists of varied parameters for the plot legend
-        if np.shape(varied_vals) == (2,2):
-            varied_vals[0] = np.repeat(varied_vals[0], 2)
-            varied_vals[1] = np.repeat(varied_vals[1], 2)
-        elif len(varied_vals[0]) == 1:
-            varied_vals[0] = np.repeat(varied_vals[0], 2)
-        else:
-            varied_vals[1] = np.repeat(varied_vals[0], 2)
-
         # Overplot the multiple fits
         for ii in range(len(sols)):
-            plot_brightness_profile(sols[ii].r, sols[ii].mean / 1e10, ax0, c=multifit_cs[ii],
-                label='{} = {}, {} = {}'.format(varied_pars[0], varied_vals[0][ii], varied_pars[1], varied_vals[1][ii]))
+            plot_brightness_profile(sols[ii].r, sols[ii].I / 1e10, ax0, c=multifit_cs[ii])#,
+                # label='alpha = {}, wsmooth = {}'.format(sols[ii].info['alpha'], sols[ii].info['wsmooth'])
             if dist and ii == len(sols) - 1:
-                ax0_5 = plot_brightness_profile(sols[ii].r, sols[ii].mean / 1e10, ax0, dist=dist, c=multifit_cs[ii])
+                ax0_5 = plot_brightness_profile(sols[ii].r, sols[ii].I / 1e10, ax0, dist=dist, c=multifit_cs[ii])
                 xlims = ax0.get_xlim()
                 ax0_5.set_xlim(np.multiply(xlims, dist))
 
-            plot_brightness_profile(sols[ii].r, sols[ii].mean / 1e10, ax1, c=multifit_cs[ii])
+            plot_brightness_profile(sols[ii].r, sols[ii].I / 1e10, ax1, c=multifit_cs[ii])
 
             vis_fit_kl = sols[ii].predict_deprojected(grid).real * 1e3
             plot_vis_quantity(grid, vis_fit_kl, ax2, c=multifit_cs[ii])
@@ -1183,10 +1169,9 @@ def make_bootstrap_fig(r, profiles, force_style=True,
         ax2.set_ylim(bottom=1e-4)
         ax3.set_ylim(bottom=1e-4)
 
-        plt.tight_layout()
-
         if save_prefix:
-            plt.savefig(save_prefix + '_frank_bootstrap.png', dpi=300)
+            plt.savefig(save_prefix + '_frank_bootstrap.png', dpi=300,
+                        bbox_inches='tight')
             plt.close()
 
     return fig, axes
